@@ -60,42 +60,42 @@ int main(int argc, char *argv[])
     }
 
     QCommandLineParser parser;
-    parser.setApplicationDescription(QApplication::tr("Customizable GUI installer for MX Linux and antiX Linux"));
+    parser.setApplicationDescription(QObject::tr("Customizable GUI installer for MX Linux and antiX Linux"));
     parser.addHelpOption();
     parser.addVersionOption();
-    parser.addOptions({{"auto", QApplication::tr("Installs automatically using the configuration file (more information below).\n"
-                                                 "-- WARNING: potentially dangerous option, it will wipe the partition(s) automatically.")},
-                       {"brave", QApplication::tr("Overrules sanity checks on partitions and drives, causing them to be displayed.\n"
-                                                  "-- WARNING: this can break things, use it only if you don't care about data on drive.")},
-                       {{"c" , "config"}, QApplication::tr("Load a configuration file as specified by <config-file>.\n"
-                                                           "By default /etc/minstall.conf is used.\n"
-                                                           "This configuration can be used with --auto for an unattended installation.\n"
-                                                           "The installer creates (or overwrites) /mnt/antiX/etc/minstall.conf and saves a copy to /etc/minstalled.conf for future use.\n"
-                                                           "The installer will not write any passwords or ignored settings to the new configuration file.\n"
-                                                           "Please note, this is experimental. Future installer versions may break compatibility with existing configuration files.")},
-                       {"gpt-override", QApplication::tr("Always use GPT when doing a whole-drive installation regardlesss of capacity.\n"
-                                                          "Without this option, GPT will only be used on drives with at least 2TB capacity.\n"
-                                                          "GPT is always used on whole-drive installations on UEFI systems regardless of capacity, even without this option.")},
-                       {{"m", "mount-keep"}, QApplication::tr("Do not unmount /mnt/antiX or close any of the associated LUKS containers when finished.")},
-                       {{"n", "nocopy"}, QApplication::tr("Another testing mode for installer, partitions/drives are going to be FORMATED, it will skip copying the files.")},
-                       {{"o", "oem"}, QApplication::tr("Install the operating system, delaying prompts for user-specific options until the first reboot.\n"
-                                                       "Upon rebooting, the installer will be run with --oobe so that the user can provide these details.\n"
-                                                       "This is useful for OEM installations, selling or giving away a computer with an OS pre-loaded on it.")},
-                       {"oobe", QApplication::tr("Out Of the Box Experience option.\n"
-                                                 "This will start automatically if installed with --oem option.")},
-                       {{"p", "pretend"}, QApplication::tr("Test mode for GUI, you can advance to different screens without actially installing.")},
-                       {{"s", "sync"}, QApplication::tr("Installing with rsync instead of cp on custom partitioning.\n"
-                                                        "-- doesn't format /root and it doesn't work with encryption.")}});
-    parser.addPositionalArgument("config-file", QApplication::tr("Load a configuration file as specified by <config-file>."), "<config-file>");
+    parser.addOptions({{"auto", QObject::tr("Installs automatically using the configuration file (more information below).\n"
+            "-- WARNING: potentially dangerous option, it will wipe the partition(s) automatically.")},
+        {"brave", QObject::tr("Overrules sanity checks on partitions and drives, causing them to be displayed.\n"
+            "-- WARNING: this can break things, use it only if you don't care about data on drive.")},
+        {{"c" , "config"}, QObject::tr("Load a configuration file as specified by <config-file>.\n"
+            "By default /etc/minstall.conf is used.\n"
+            "This configuration can be used with --auto for an unattended installation.\n"
+            "The installer creates (or overwrites) /mnt/antiX/etc/minstall.conf and saves a copy to /etc/minstalled.conf for future use.\n"
+            "The installer will not write any passwords or ignored settings to the new configuration file.\n"
+            "Please note, this is experimental. Future installer versions may break compatibility with existing configuration files.")},
+        {"gpt-override", QObject::tr("Always use GPT when doing a whole-drive installation regardlesss of capacity.\n"
+            "Without this option, GPT will only be used on drives with at least 2TB capacity.\n"
+            "GPT is always used on whole-drive installations on UEFI systems regardless of capacity, even without this option.")},
+        {{"m", "mount-keep"}, QObject::tr("Do not unmount /mnt/antiX or close any of the associated LUKS containers when finished.")},
+        {{"n", "nocopy"}, QObject::tr("Another testing mode for installer, partitions/drives are going to be FORMATED, it will skip copying the files.")},
+        {{"o", "oem"}, QObject::tr("Install the operating system, delaying prompts for user-specific options until the first reboot.\n"
+            "Upon rebooting, the installer will be run with --oobe so that the user can provide these details.\n"
+            "This is useful for OEM installations, selling or giving away a computer with an OS pre-loaded on it.")},
+        {"oobe", QObject::tr("Out Of the Box Experience option.\n"
+            "This will start automatically if installed with --oem option.")},
+        {{"p", "pretend"}, QObject::tr("Test mode for GUI, you can advance to different screens without actially installing.")},
+        {{"s", "sync"}, QObject::tr("Installing with rsync instead of cp on custom partitioning.\n"
+            "-- doesn't format /root and it doesn't work with encryption.")}});
+    parser.addPositionalArgument("config-file", QObject::tr("Load a configuration file as specified by <config-file>."), "<config-file>");
     parser.process(a);
 
     if (parser.positionalArguments().size() > 1) {
-        qDebug() << QApplication::tr("Too many arguments. Please check the command format by running the program with --help");
+        qDebug() << QObject::tr("Too many arguments. Please check the command format by running the program with --help");
         return EXIT_FAILURE;
     }
 
     QSettings appConf("/usr/share/gazelle-installer-data/installer.conf", QSettings::NativeFormat);
-    a.setApplicationDisplayName(a.tr("%1 Installer").arg(appConf.value("PROJECT_NAME").toString()));
+    a.setApplicationDisplayName(QObject::tr("%1 Installer").arg(appConf.value("PROJECT_NAME").toString()));
 
     // The lock is released when this object is destroyed.
     QLockFile lockfile("/var/lock/gazelle-installer.lock");
@@ -103,14 +103,14 @@ int main(int argc, char *argv[])
         // Set Lock or exit if lockfile is present.
         if (!lockfile.tryLock()) {
             QMessageBox::critical(nullptr, QString(),
-                QApplication::tr("The installer won't launch because it appears to be running already in the background.\n\n"
+                QObject::tr("The installer won't launch because it appears to be running already in the background.\n\n"
                     "Please close it if possible, or run 'pkill minstall' in terminal."));
             return EXIT_FAILURE;
         }
         // Alert the user if not running as root.
         if (getuid() != 0) {
             QMessageBox::critical(nullptr, QString(),
-                QApplication::tr("This operation requires root access."));
+                QObject::tr("This operation requires root access."));
             return EXIT_FAILURE;
         }
     }
@@ -128,19 +128,26 @@ int main(int argc, char *argv[])
         // give error message and exit if no config file found
         if (! QFile::exists(cfgfile)) {
             QMessageBox::warning(nullptr, QString(),
-                QApplication::tr("Configuration file (%1) not found.").arg(cfgfile));
+                QObject::tr("Configuration file (%1) not found.").arg(cfgfile));
             return EXIT_FAILURE;
         }
     }
 
     // main routine
     qDebug() << "Installer version:" << VERSION;
-    MInstall minstall(appConf, parser, cfgfile);
-    const QRect &geo = a.desktop()->availableGeometry(&minstall);
-    if (parser.isSet("oobe")) minstall.setGeometry(geo);
-    else minstall.move((geo.width() - minstall.width()) / 2, (geo.height() - minstall.height()) / 2);
-    minstall.show();
-    return a.exec();
+    try {
+        MInstall minstall(appConf, parser, cfgfile);
+        const QRect &geo = a.desktop()->availableGeometry(&minstall);
+        if (parser.isSet("oobe")) minstall.setGeometry(geo);
+        else minstall.move((geo.width() - minstall.width()) / 2, (geo.height() - minstall.height()) / 2);
+        minstall.show();
+        return a.exec();
+    } catch (const char *msg) {
+        qDebug() << "ERROR:" << msg;
+        QMessageBox::critical(nullptr, QString(), QObject::tr(msg));
+        return EXIT_FAILURE;
+    }
+    return EXIT_SUCCESS;
 }
 
 // The implementation of the handler
